const { openBlock, createElementBlock, createElementVNode, normalizeClass, toDisplayString, createVNode, Transition, withCtx, createCommentVNode, withDirectives, vModelText, Fragment, renderList, createTextVNode, normalizeStyle, createStaticVNode } = Vue;

const SCRIPT_ID = 'tradingview-widget-script';
const CONTAINER_ID = 'vue-trading-view';
  
var script = {
  data() {
    return {
      sock: null,
      status: 0,
      tickers: {},
      cache: [],
      trades: [],
      favorites: ['BTCUSDT'],
      interval: '1d',
      digitalClock: null,
      asks: [],
      bids: [],
      maxAsk: 0,
      bgImageUrl: null,
      showSettings: false,
      showLatestTrades: true,
      inputSearch: '',
      asset: 'USDT',
      sort: 'assetVolume',
      order: 'desc', 
      //chart
      ticker: 'BTCUSDT',
      container_id: CONTAINER_ID,
      change: 'change',
      options: {
        autosize: true,
        symbol: 'BINANCE:BTCUSDT',
        interval: '5',
        timezone: 'Asia/Jerusalem',
        theme: 'dark',
        style: '1',
        locale: 'en',
        toolbar_bg: '#f1f3f6',
        enable_publishing: false,
        withdateranges: true,
        hide_side_toolbar: false,
        allow_symbol_change: true,
        save_image: true,
        // watchlist: [
        //   'BITMEX:XBTUSD.P',
        //   'BINANCE:XMRBTC',
        // ],
        details: false,
        hotlist: false,
        studies: [
          // 'IchimokuCloud@tv-basicstudies',
          {
            id: 'VWAP@tv-basicstudies',
          },
          {
            id: 'MAExp@tv-basicstudies',
            inputs: {
              length: 200
            },
            styles: {
            }
          }
        ],
      }

    };
  },
  methods: {
    toggleSettings() {
      this.showSettings = !this.showSettings;
    },
    toggleLatestTrades() {
      this.showLatestTrades = !this.showLatestTrades;
    },
    startClock() {
      this.digitalClock = new Date(Date.now()).toLocaleTimeString("en-GB");
      setTimeout(() => { this.startClock(); }, 250);
    },
    changeTicker(symbol) {
      this.unsubscribeTicker();
      this.ticker = symbol;
      this.setSymbol(symbol);
      this.subscribeTicker();
    },
    setSymbol(symbol) {
      var elIframeWidget = document.querySelectorAll("iframe[id*=tradingview_]")[0];

			if (
				!elIframeWidget ||
				!elIframeWidget.contentWindow
			) {
				return;
			}
     
			elIframeWidget.contentWindow.postMessage(
				{
					name: 'set-symbol',
					data: {
						symbol: symbol,
					},
				},
				'*'
			);
		},
    canUseDOM() {
      return typeof window !== 'undefined' && window.document && window.document.createElement;
    },
    getScriptElement() {
      return document.getElementById(SCRIPT_ID);
    },
    updateOnloadListener(onload) {
      const script = this.getScriptElement();
      const oldOnload = script.onload;
      return script.onload = () => {
        oldOnload();
        onload();
      };
    },
    scriptExists() {
      return this.getScriptElement() !== null;
    },
    appendScript(onload) {
      if (!this.canUseDOM()) {
        onload();
        return;
      }

      if (this.scriptExists()) {
        if (typeof TradingView === 'undefined') {
          this.updateOnloadListener(onload);
          return;
        }
        onload();
        return;
      }
      const script = document.createElement('script');
      script.id = SCRIPT_ID;
      script.type = 'text/javascript';
      script.async = true;
      script.src = 'https://s3.tradingview.com/tv.js';
      script.onload = onload;
      document.getElementsByTagName('head')[0].appendChild(script);
    },
    initWidget() {
      if (typeof TradingView === 'undefined') { return; }
      new window.TradingView.widget(
        Object.assign({ container_id: this.container_id }, this.options)
      );
    },
    sockInit() {
      if ( this.status > 0 ) return;
      try {
        this.status = 0;
        
        this.sock = new WebSocket( 'wss://stream.binance.com:9443/ws/!ticker@arr' );
        this.sock.addEventListener( 'open', this.onSockOpen );
        this.sock.addEventListener( 'close', this.onSockClose );
        this.sock.addEventListener( 'error', this.onSockError );
        this.sock.addEventListener( 'message', this.onSockData );
      }
      catch( err ) {
        console.error( 'WebSocketError:', err.message || err );
        this.status = -1; // error
        this.sock = null;
      }
    },
    onSockData( e ) {
      let list = JSON.parse( e.data ) || [];
      if ( list['error'] ) { console.error(e); }
      if (list.id > 0) { return; }
      
      if (list.e === 'aggTrade') {
        this.trades.unshift([list.E, list.p, list.q, list.m]);
        if (this.trades.length >= 200) {
          this.trades = this.trades.slice(0, 150);
        }
        return;
      }
      if (list.e === 'depthUpdate') ;
        
      if (list.e === undefined) {
        for (let item of list) {
          let coin = this.getCoinData(item);
          this.tickers[coin.symbol] = coin;
          if ( coin.symbol === this.ticker) {
            this.status = 2;
          }
        }
        this.cache = Object.keys( this.tickers ).map( s => this.tickers[ s ] );

      }
      
    },
    onSockOpen() {
      this.status = 1; // open
      console.info( 'WebSocketInfo:', 'Connection open.' );
      this.subscribeTicker();
    },
    onSockError( err ) {
      this.status = 0; // error
      console.error( 'WebSocketError:', err.message || err );
      setTimeout(() => { this.sockInit(); }, 10000); // try again
    },
    onSockClose() {
      this.status = 0; // closed
      console.info( 'WebSocketInfo:', 'Connection closed.' );
      setTimeout(() => { this.sockInit(); }, 10000); // try again
    },
    sockClose() {
      if ( this.sock ) {
        this.sock.close();
      }
    },
    subscribeTicker() {
      let streams = {
        "method": "SUBSCRIBE",
        "params": [
          this.ticker.toLowerCase() + "@aggTrade",
          this.ticker.toLowerCase() + "@depth",
          // this.ticker.toLowerCase() + "@kline_"+this.interval
        ],
        "id": 1
      };
      
      this.sock.send(JSON.stringify(streams));
    },
    unsubscribeTicker() {
      this.trades = [];
      this.depth = [];
      let streams = {
        "method": "UNSUBSCRIBE",
        "params": [
          this.ticker.toLowerCase() + "@aggTrade",
          this.ticker.toLowerCase() + "@depth",
          // this.ticker.toLowerCase() + "@kline_"+this.interval
        ],
        "id": 2
      };
      this.sock.send(JSON.stringify(streams));
    },
    getCoinData(item) {
         let reg = /^([A-Z]+)(BTC|ETH|BNB|USDT|TUSD)$/;
         let symbol = String(item.s).replace(/[^\w\-]+/g, "").toUpperCase();
         let token = symbol.replace(reg, "$1");
         let asset = symbol.replace(reg, "$2");
         let name = token;
         let pair = token + "/" + asset;
         let icon = "/" + token.toLowerCase() + "_.png";
         let open = parseFloat(item.o);
         let high = parseFloat(item.h);
         let low = parseFloat(item.l);
         let close = parseFloat(item.c);
         let change = parseFloat(item.p);
         let percent = parseFloat(item.P);
         let trades = parseInt(item.n);
         let tokenVolume = Math.round(item.v);
         let assetVolume = Math.round(item.q);
         let sign = percent >= 0 ? "+" : "";
         let arrow = percent >= 0 ? "▲" : "▼";
         let info = [
            pair,
            close.toFixed(8),
            "(",
            arrow,
            sign + percent.toFixed(2) + "%",
            "|",
            sign + change.toFixed(8),
            ")"
         ].join(" ");
         let style = "";

         if (percent > 0) style = "green";
         if (percent < 0) style = "red";

         return {
            symbol,
            token,
            asset,
            name,
            pair,
            icon,
            open,
            high,
            low,
            close,
            change,
            percent,
            trades,
            tokenVolume,
            assetVolume,
            sign,
            arrow,
            style,
            info
         };
      },
    parseNumber(number, currency = '') {
    // const formatters = {
    //     default: new Intl.NumberFormat(),
    //     currency: new Intl.NumberFormat('en-US', { style: 'currency', currency: 'USD', minimumFractionDigits: 0, maximumFractionDigits: 0 }),
    //     whole: new Intl.NumberFormat('en-US', { style: 'decimal', minimumFractionDigits: 0, maximumFractionDigits: 0 }),
    //     oneDecimal: new Intl.NumberFormat('en-US', { style: 'decimal', minimumFractionDigits: 1, maximumFractionDigits: 1 }),
    //     twoDecimal: new Intl.NumberFormat('en-US', { style: 'decimal', minimumFractionDigits: 2, maximumFractionDigits: 2 })
    // };
      if ( currency.includes(['USDT'])) {
        return new Intl.NumberFormat('en-US', { style: 'currency', currency: 'USD' , trailingZeroDisplay: 'stripIfInteger'}).format(number);
      }
      return new Intl.NumberFormat('en-US', { minimumFractionDigits: 10, trailingZeroDisplay: 'stripIfInteger' }).format(number);
    },
    timestampToDate(timestamp) {
      var options = {
        hour: "numeric",
        minute: "numeric",
        second: "numeric",
        hour12: false,
        timeZone: "Asia/Jerusalem",
      };
      return new Intl.DateTimeFormat("en-GB", options).format(timestamp);
    },
    setFavorite(symbol) {
      var index = this.favorites.indexOf(symbol);
      if (index >= 0) {
        delete this.favorites[index];
      } else {
        this.favorites.push(symbol);
      }
    },
    filterAsset( asset ) {
      this.asset = String( asset || this.asset );
    },
    quickSort(arr, key, order) {
      if (arr.length <= 1) {
        return arr;
      }

      const pivotIndex = Math.floor(arr.length / 2);
      const pivot = arr[pivotIndex];
      const left = [];
      const right = [];

      for (let i = 0; i < arr.length; i++) {
        if (i === pivotIndex) {
          continue;
        }

        if (order === 'asc') {
          arr[i][key] < pivot[key] ? left.push(arr[i]) : right.push(arr[i]);
        } else {
          arr[i][key] > pivot[key] ? left.push(arr[i]) : right.push(arr[i]);
        }
      }

      return [...this.quickSort(left, key, order), pivot, ...this.quickSort(right, key, order)];
    },
    sortBy( key, order ) {
      if ( this.sort !== key ) { this.order = order || 'asc'; }
      else { this.order = ( this.order === 'asc' ) ? 'desc' : 'asc'; }
      this.sort = key;
    },
    async prepareOrderBook() {
      await fetch('https://api.binance.com/api/v3/depth?symbol=' + this.ticker + '&limit=100')
      .then(response => response.text())
      .then(data => {
        let depth = JSON.parse(data);
        this.asks = depth.asks;
        this.bids = depth.bids;
        
        for (let i = 0; i < this.asks.length; i++) {
          var arr = this.asks.map(x => {
            return Number(x[1]);
          });
          this.asks[i].push(arr.slice(0, i+1).reduce((a,b)=>a+b));
        }
        for (let i = 0; i < this.bids.length; i++) {
          var arr = this.bids.map(x => {
            return Number(x[1]);
          });
          this.bids[i].push(arr.slice(0, i+1).reduce((a,b)=>a+b));
        }
      });
      
      this.maxAsk = Math.max(...this.asks.map(x => { return x[2] }));
      setTimeout(async () => { await this.prepareOrderBook(); }, 500);
    },
  },
  mounted() {
    this.sockInit();
    this.startClock();
    this.appendScript(this.initWidget);
    this.prepareOrderBook();
  },
  unmounted() {
    this.sockClose();
  },
  computed: {
    statusMsg() {
      let msg = '';
      if (this.status == 0) {
        msg = 'Connecting...';
      }
      if (this.status == 1) {
        msg = 'Loading...';
      }
      if (this.status == 2) {
        msg = 'Done';
      }
      return msg;
    },
    latestTrades() {
      if (!this.showLatestTrades) {return;}
      return this.trades;
    },
    filterTickers() {
      let tickers = this.cache;
      // filter by search
      tickers = this.cache.filter(x => x.symbol.startsWith(this.inputSearch.toUpperCase()));
      // filter by asset
      if ( this.asset == 'FAV') {
          tickers = tickers.filter( i => this.favorites.includes(i.symbol) );
        } else {
          tickers = tickers.filter( i => i.asset === this.asset );
        }
      // sort
      tickers = this.quickSort( tickers, this.sort, this.order );

      return tickers;
    },
  }
};

const _hoisted_1 = { class: "relative p-4" };
const _hoisted_2 = { class: "flex relative h-14 gap-4 items-center justify-between px-2 text-sm lg:text-xl" };
const _hoisted_3 = { class: "flex items-center" };
const _hoisted_4 = /*#__PURE__*/createStaticVNode("<svg version=\"1.1\" x=\"0px\" y=\"0px\" width=\"32px\" height=\"32px\" viewBox=\"0 0 126.611 126.611\"><polygon fill=\"#F3BA2F\" points=\"38.171,53.203 62.759,28.616 87.36,53.216 101.667,38.909 62.759,0 23.864,38.896 \"></polygon><rect x=\"3.644\" y=\"53.188\" transform=\"matrix(0.7071 0.7071 -0.7071 0.7071 48.7933 8.8106)\" fill=\"#F3BA2F\" width=\"20.233\" height=\"20.234\"></rect><polygon fill=\"#F3BA2F\" points=\"38.171,73.408 62.759,97.995 87.359,73.396 101.674,87.695 101.667,87.703 62.759,126.611 \n\t23.863,87.716 23.843,87.696 \"></polygon><rect x=\"101.64\" y=\"53.189\" transform=\"matrix(-0.7071 0.7071 -0.7071 -0.7071 235.5457 29.0503)\" fill=\"#F3BA2F\" width=\"20.234\" height=\"20.233\"></rect><polygon fill=\"#F3BA2F\" points=\"77.271,63.298 77.277,63.298 62.759,48.78 52.03,59.509 52.029,59.509 50.797,60.742 48.254,63.285 \n\t48.254,63.285 48.234,63.305 48.254,63.326 62.759,77.831 77.277,63.313 77.284,63.305 \"></polygon></svg>", 1);
const _hoisted_5 = { class: "clock" };
const _hoisted_6 = {
  key: 0,
  class: "flex flex-grow justify-center absolute w-full"
};
const _hoisted_7 = { class: "animate-pulse" };
const _hoisted_8 = {
  key: 0,
  class: "flex gap-2 flex-grow items-center justify-between delay-200"
};
const _hoisted_9 = { class: "w-1/2" };
const _hoisted_10 = { class: "flex gap-2" };
const _hoisted_11 = { class: "mr-1" };
const _hoisted_12 = { class: "w-1/2" };
const _hoisted_13 = /*#__PURE__*/createElementVNode("small", { class: "block" }, "24H Highest", -1 /* HOISTED */);
const _hoisted_14 = { class: "w-1/2" };
const _hoisted_15 = /*#__PURE__*/createElementVNode("small", { class: "block" }, "24H Lowest", -1 /* HOISTED */);
const _hoisted_16 = { class: "w-1/2 hidden" };
const _hoisted_17 = /*#__PURE__*/createElementVNode("small", { class: "block" }, "24H Volume", -1 /* HOISTED */);
const _hoisted_18 = { class: "w-1/2 hidden" };
const _hoisted_19 = /*#__PURE__*/createElementVNode("small", { class: "block" }, "24H Value", -1 /* HOISTED */);
const _hoisted_20 = /*#__PURE__*/createElementVNode("svg", {
  class: "hover:fill-[--color-primary-blue]",
  xmlns: "http://www.w3.org/2000/svg",
  width: "24",
  height: "24",
  viewBox: "0 0 24 24"
}, [
  /*#__PURE__*/createElementVNode("path", { d: "M24 13.616v-3.232c-1.651-.587-2.694-.752-3.219-2.019v-.001c-.527-1.271.1-2.134.847-3.707l-2.285-2.285c-1.561.742-2.433 1.375-3.707.847h-.001c-1.269-.526-1.435-1.576-2.019-3.219h-3.232c-.582 1.635-.749 2.692-2.019 3.219h-.001c-1.271.528-2.132-.098-3.707-.847l-2.285 2.285c.745 1.568 1.375 2.434.847 3.707-.527 1.271-1.584 1.438-3.219 2.02v3.232c1.632.58 2.692.749 3.219 2.019.53 1.282-.114 2.166-.847 3.707l2.285 2.286c1.562-.743 2.434-1.375 3.707-.847h.001c1.27.526 1.436 1.579 2.019 3.219h3.232c.582-1.636.75-2.69 2.027-3.222h.001c1.262-.524 2.12.101 3.698.851l2.285-2.286c-.744-1.563-1.375-2.433-.848-3.706.527-1.271 1.588-1.44 3.221-2.021zm-12 2.384c-2.209 0-4-1.791-4-4s1.791-4 4-4 4 1.791 4 4-1.791 4-4 4z" })
], -1 /* HOISTED */);
const _hoisted_21 = [
  _hoisted_20
];
const _hoisted_22 = /*#__PURE__*/createElementVNode("div", { class: "delimiter my-4" }, null, -1 /* HOISTED */);
const _hoisted_23 = { class: "mb-4" };
const _hoisted_24 = { class: "flex gap-4 flex-col lg:flex-row" };
const _hoisted_25 = { class: "tickers w-[500px]" };
const _hoisted_26 = { class: "mb-2" };
const _hoisted_27 = /*#__PURE__*/createElementVNode("h2", { class: "text-glow font-bold text-xl" }, "Ticker List", -1 /* HOISTED */);
const _hoisted_28 = /*#__PURE__*/createElementVNode("div", { class: "delimiter2 my-4" }, null, -1 /* HOISTED */);
const _hoisted_29 = { class: "cb flex items-center" };
const _hoisted_30 = /*#__PURE__*/createElementVNode("div", { class: "h-5 w-5 ml-3 mr-4" }, [
  /*#__PURE__*/createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "0 0 24 24"
  }, [
    /*#__PURE__*/createElementVNode("path", { d: "M21.172 24l-7.387-7.387c-1.388.874-3.024 1.387-4.785 1.387-4.971 0-9-4.029-9-9s4.029-9 9-9 9 4.029 9 9c0 1.761-.514 3.398-1.387 4.785l7.387 7.387-2.828 2.828zm-12.172-8c3.859 0 7-3.14 7-7s-3.141-7-7-7-7 3.14-7 7 3.141 7 7 7z" })
  ])
], -1 /* HOISTED */);
const _hoisted_31 = { class: "mb-2" };
const _hoisted_32 = { class: "flex gap-2 justify-between h-10" };
const _hoisted_33 = { class: "cb pr-4 pb-4" };
const _hoisted_34 = { class: "header flex items-center h-8 px-2 cursor-pointer" };
const _hoisted_35 = { class: "body h-[454px] relative overflow-y-scroll px-2" };
const _hoisted_36 = {
  key: 0,
  class: "h-full flex items-center justify-center"
};
const _hoisted_37 = /*#__PURE__*/createElementVNode("svg", {
  class: "animate-spin -ml-1 mr-3 h-5 w-5 text-white",
  xmlns: "http://www.w3.org/2000/svg",
  fill: "none",
  viewBox: "0 0 24 24"
}, [
  /*#__PURE__*/createElementVNode("circle", {
    class: "opacity-25",
    cx: "12",
    cy: "12",
    r: "10",
    stroke: "currentColor",
    "stroke-width": "4"
  }),
  /*#__PURE__*/createElementVNode("path", {
    class: "opacity-75",
    fill: "var(--color-primary-yellow)",
    d: "M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"
  })
], -1 /* HOISTED */);
const _hoisted_38 = [
  _hoisted_37
];
const _hoisted_39 = { key: 1 };
const _hoisted_40 = ["onClick"];
const _hoisted_41 = ["onClick"];
const _hoisted_42 = ["onClick"];
const _hoisted_43 = { class: "w-1/4 dotdotdot silver text-end flex gap-2 justify-end" };
const _hoisted_44 = ["onClick"];
const _hoisted_45 = ["onClick"];
const _hoisted_46 = /*#__PURE__*/createElementVNode("path", { d: "M12 .587l3.668 7.568 8.332 1.151-6.064 5.828 1.48 8.279-7.416-3.967-7.417 3.967 1.481-8.279-6.064-5.828 8.332-1.151z" }, null, -1 /* HOISTED */);
const _hoisted_47 = [
  _hoisted_46
];
const _hoisted_48 = { class: "chart flex-grow" };
const _hoisted_49 = { class: "flex items-center justify-between" };
const _hoisted_50 = /*#__PURE__*/createElementVNode("h2", { class: "text-glow font-bold text-xl" }, "TradingView Chart", -1 /* HOISTED */);
const _hoisted_51 = /*#__PURE__*/createElementVNode("svg", {
  class: "hover:fill-[--color-primary-blue]",
  xmlns: "http://www.w3.org/2000/svg",
  width: "14",
  height: "14",
  viewBox: "0 0 24 24"
}, [
  /*#__PURE__*/createElementVNode("path", { d: "M24 13.616v-3.232c-1.651-.587-2.694-.752-3.219-2.019v-.001c-.527-1.271.1-2.134.847-3.707l-2.285-2.285c-1.561.742-2.433 1.375-3.707.847h-.001c-1.269-.526-1.435-1.576-2.019-3.219h-3.232c-.582 1.635-.749 2.692-2.019 3.219h-.001c-1.271.528-2.132-.098-3.707-.847l-2.285 2.285c.745 1.568 1.375 2.434.847 3.707-.527 1.271-1.584 1.438-3.219 2.02v3.232c1.632.58 2.692.749 3.219 2.019.53 1.282-.114 2.166-.847 3.707l2.285 2.286c1.562-.743 2.434-1.375 3.707-.847h.001c1.27.526 1.436 1.579 2.019 3.219h3.232c.582-1.636.75-2.69 2.027-3.222h.001c1.262-.524 2.12.101 3.698.851l2.285-2.286c-.744-1.563-1.375-2.433-.848-3.706.527-1.271 1.588-1.44 3.221-2.021zm-12 2.384c-2.209 0-4-1.791-4-4s1.791-4 4-4 4 1.791 4 4-1.791 4-4 4z" })
], -1 /* HOISTED */);
const _hoisted_52 = [
  _hoisted_51
];
const _hoisted_53 = /*#__PURE__*/createElementVNode("div", { class: "delimiter2 my-4" }, null, -1 /* HOISTED */);
const _hoisted_54 = { class: "cb relative" };
const _hoisted_55 = ["id"];
const _hoisted_56 = { class: "w-[500px]" };
const _hoisted_57 = /*#__PURE__*/createStaticVNode("<h2 class=\"text-glow font-bold text-xl flex items-center\">Make Order</h2><div class=\"delimiter2 my-4\"></div><div class=\"flex gap-4 bg-[--color-bg--300] px-6 pb-5 pt-3 border border-[--color-primary--600]\"><div class=\"w-1/2\"><span class=\"text-[--color-primary-blue] font-bold text-xl\">Price</span><div class=\"cb mb-2\"><input class=\"bg-transparent h-10 w-full focus:outline-none pl-4 text-xl font-semibold\"></div><div class=\"cb-style3\"><div class=\"relative flex gap-2 items-center justify-center\"> Buy </div></div></div><div class=\"w-1/2\"><span class=\"text-[--color-primary-blue] font-bold text-xl text-end w-full block\">Amount</span><div class=\"cb cb-reverse mb-2\"><input class=\"bg-transparent h-10 focus:outline-none pr-4 text-xl text-end font-semibold\"></div><div class=\"cb-style3 cb-style3-left\"><div class=\"relative flex gap-2 items-center justify-center min-w-0\">Sell </div></div></div></div><div class=\"delimiter2 my-4\"></div>", 4);
const _hoisted_61 = /*#__PURE__*/createElementVNode("h2", { class: "text-glow font-bold text-xl flex items-center" }, "Order Book", -1 /* HOISTED */);
const _hoisted_62 = /*#__PURE__*/createElementVNode("div", { class: "delimiter2 my-4" }, null, -1 /* HOISTED */);
const _hoisted_63 = { class: "cb pr-4 pb-4" };
const _hoisted_64 = /*#__PURE__*/createStaticVNode("<div class=\"flex gap-2 items-center h-8 px-2\"><div class=\"flex flex-1 text-[--color-primary-green]\"><div class=\"w-1/3\">Total</div><div class=\"w-1/3 text-center\">Size</div><div class=\"w-1/3 text-end\">Price</div></div><div class=\"flex flex-1\"><div class=\"w-1/3\">Price</div><div class=\"w-1/3 text-center\">Size</div><div class=\"w-1/3 text-end\">Total</div></div></div>", 1);
const _hoisted_65 = { class: "h-[296px] relative overflow-y-scroll px-2" };
const _hoisted_66 = { class: "flex gap-2 flex-row" };
const _hoisted_67 = { class: "flex-1" };
const _hoisted_68 = { class: "w-1/3 flex-1 text-[--color-primary-silver]" };
const _hoisted_69 = { class: "w-1/3 flex-1 text-center text-[--color-primary-silver]" };
const _hoisted_70 = { class: "w-1/3 flex-1 text-end text-[--color-primary-green]" };
const _hoisted_71 = { class: "flex-1" };
const _hoisted_72 = { class: "w-1/3 flex-1 text-left" };
const _hoisted_73 = { class: "w-1/3 flex-1 text-center text-[--color-primary-silver]" };
const _hoisted_74 = { class: "w-1/3 flex-1 text-end text-[--color-primary-silver]" };
const _hoisted_75 = { class: "flex gap-4" };
const _hoisted_76 = /*#__PURE__*/createStaticVNode("<div class=\"orders flex-grow\"><div class=\"flex gap-4\"><div class=\"cb_tab active\"><div>Current Orders</div></div><div class=\"cb_tab\"><div>History Orders</div></div></div><div class=\"delimiter2 my-4\"></div><div class=\"header flex gap-2 justify-between px-2 mb-4 font-semibold\"><div>Time</div><div class=\"text-center\">Market</div><div class=\"text-center\">Side</div><div class=\"text-end\">Price</div><div class=\"text-end\">Amount</div><div class=\"text-end\">Executed</div><div class=\"text-end\">Options</div></div><div class=\"body flex gap-2 justify-between px-2 mb-1 silver cb h-6\"><div>12.23.2023 12:22</div><div class=\"text-center text-[--color-primary--500]\">BTC/USDT</div><div class=\"text-center text-[--color-primary--500]\">Sell</div><div class=\"text-end\">22333</div><div class=\"text-end\">0.88</div><div class=\"text-end\">0</div><div class=\"flex items-center justify-end cursor-pointer\"><span class=\"mr-4 bg-[--color-primary-blue] rounded-full w-3 h-3 block border-1 border-[--color-primary-black] flex items-center justify-center\"><svg class=\"fill-[--color-primary-black]\" xmlns=\"http://www.w3.org/2000/svg\" width=\"6\" height=\"6\" viewBox=\"0 0 24 24\"><path d=\"M24 3.752l-4.423-3.752-7.771 9.039-7.647-9.008-4.159 4.278c2.285 2.885 5.284 5.903 8.362 8.708l-8.165 9.447 1.343 1.487c1.978-1.335 5.981-4.373 10.205-7.958 4.304 3.67 8.306 6.663 10.229 8.006l1.449-1.278-8.254-9.724c3.287-2.973 6.584-6.354 8.831-9.245z\"></path></svg></span></div></div><div class=\"body flex gap-2 justify-between px-2 mb-1 silver cb h-6\"><div>12.23.2023 12:22</div><div class=\"text-center text-[--color-primary-green]\">BTC/USDT</div><div class=\"text-center text-[--color-primary-green]\">Buy</div><div class=\"text-end\">22333</div><div class=\"text-end\">0.88</div><div class=\"text-end\">0</div><div class=\"flex items-center justify-end cursor-pointer\"><span class=\"mr-4 bg-[--color-primary-blue] rounded-full w-3 h-3 block border-1 border-[--color-primary-black] flex items-center justify-center\"><svg class=\"fill-[--color-primary-black]\" xmlns=\"http://www.w3.org/2000/svg\" width=\"6\" height=\"6\" viewBox=\"0 0 24 24\"><path d=\"M24 3.752l-4.423-3.752-7.771 9.039-7.647-9.008-4.159 4.278c2.285 2.885 5.284 5.903 8.362 8.708l-8.165 9.447 1.343 1.487c1.978-1.335 5.981-4.373 10.205-7.958 4.304 3.67 8.306 6.663 10.229 8.006l1.449-1.278-8.254-9.724c3.287-2.973 6.584-6.354 8.831-9.245z\"></path></svg></span></div></div></div>", 1);
const _hoisted_77 = { class: "tickers w-[500px] flex flex-col gap-4" };
const _hoisted_78 = { class: "w-full" };
const _hoisted_79 = { class: "flex justify-between items-center" };
const _hoisted_80 = /*#__PURE__*/createElementVNode("h2", { class: "text-glow font-bold text-xl h-[50px] flex items-center" }, "Latest Trades", -1 /* HOISTED */);
const _hoisted_81 = /*#__PURE__*/createElementVNode("path", {
  d: "m11.998 5c-4.078 0-7.742 3.093-9.853 6.483-.096.159-.145.338-.145.517s.048.358.144.517c2.112 3.39 5.776 6.483 9.854 6.483 4.143 0 7.796-3.09 9.864-6.493.092-.156.138-.332.138-.507s-.046-.351-.138-.507c-2.068-3.403-5.721-6.493-9.864-6.493zm8.413 7c-1.837 2.878-4.897 5.5-8.413 5.5-3.465 0-6.532-2.632-8.404-5.5 1.871-2.868 4.939-5.5 8.404-5.5 3.518 0 6.579 2.624 8.413 5.5zm-8.411-4c2.208 0 4 1.792 4 4s-1.792 4-4 4-4-1.792-4-4 1.792-4 4-4zm0 1.5c-1.38 0-2.5 1.12-2.5 2.5s1.12 2.5 2.5 2.5 2.5-1.12 2.5-2.5-1.12-2.5-2.5-2.5z",
  "fill-rule": "nonzero"
}, null, -1 /* HOISTED */);
const _hoisted_82 = [
  _hoisted_81
];
const _hoisted_83 = /*#__PURE__*/createElementVNode("div", { class: "delimiter2 my-4" }, null, -1 /* HOISTED */);
const _hoisted_84 = { class: "cb pb-4" };
const _hoisted_85 = /*#__PURE__*/createElementVNode("div", { class: "header flex items-center h-8 px-2" }, [
  /*#__PURE__*/createElementVNode("div", { class: "w-1/3" }, "Time"),
  /*#__PURE__*/createElementVNode("div", { class: "w-1/3 text-end" }, "Price"),
  /*#__PURE__*/createElementVNode("div", { class: "w-1/3 text-end pr-4" }, "Volume")
], -1 /* HOISTED */);
const _hoisted_86 = { class: "h-[250px] mr-4 relative overflow-y-scroll px-2" };
const _hoisted_87 = {
  class: "flex",
  style: {"font-family":"'Roboto Mono', monospace"}
};
const _hoisted_88 = { class: "w-1/3 silver" };
const _hoisted_89 = { class: "w-1/3 silver text-end" };
const _hoisted_90 = {
  key: 0,
  id: "staticModal",
  class: "bg-[#00000080] fixed flex items-center justify-center top-0 left-0 right-0 z-50 w-full p-4 overflow-x-hidden overflow-y-auto md:inset-0 h-[calc(100%-1rem)] max-h-full"
};
const _hoisted_91 = { class: "relative w-full max-w-2xl max-h-full" };
const _hoisted_92 = { class: "relative" };
const _hoisted_93 = { class: "flex" };
const _hoisted_94 = /*#__PURE__*/createElementVNode("div", { class: "cb-left mr-[1px]" }, [
  /*#__PURE__*/createElementVNode("div")
], -1 /* HOISTED */);
const _hoisted_95 = { class: "cb !bg-[--color-primary-black] px-6 py-2 w-full" };
const _hoisted_96 = /*#__PURE__*/createStaticVNode("<p class=\"uppercase text-xl border-b-[1px] border-[#441618] pb-1 mb-2\"> Settings </p><p class=\"uppercase text-xl text-[--color-primary-blue]\"> Enable trading </p><p class=\"mb-2\">Toggle ON or OFF the ability to trade on this terminal.</p><label class=\"relative inline-flex items-center cursor-pointer\"><input type=\"checkbox\" value=\"\" class=\"sr-only peer\"><div class=\"w-11 h-6 bg-gray-200 peer-focus:outline-none peer-focus:ring-4 peer-focus:ring-blue-300 dark:peer-focus:ring-blue-800 rounded-full peer dark:bg-gray-700 peer-checked:after:translate-x-full peer-checked:after:border-white after:content-[&#39;&#39;] after:absolute after:top-[2px] after:left-[2px] after:bg-white after:border-gray-300 after:border after:rounded-full after:h-5 after:w-5 after:transition-all dark:border-gray-600 peer-checked:bg-blue-600\"></div><span class=\"ml-3 text-sm font-medium text-gray-900 dark:text-gray-300\">Enable trading</span></label><p class=\"uppercase text-xl text-[--color-primary-blue]\">API KEY</p><p class=\"mb-2\">Enter your API KEY from Binance Test and allow IP address <span class=\"text-[--color-primary-yellow]\">127.0.0.1</span>.</p><div class=\"cb w-96\"><input class=\"h-10 w-full px-4 bg-transparent focus:outline-none\" placeholder=\"Do not enter any live API KEY!\"></div><div class=\"delimiter-blue my-4\"></div><p class=\"uppercase text-xl text-[--color-primary-blue]\">Show latest trades</p><p class=\"mb-2\">Toggle ON or OFF the visibility for the latest trades.</p>", 10);
const _hoisted_106 = ["checked"];
const _hoisted_107 = /*#__PURE__*/createElementVNode("div", { class: "w-11 h-6 bg-gray-200 peer-focus:outline-none peer-focus:ring-4 peer-focus:ring-blue-300 dark:peer-focus:ring-blue-800 rounded-full peer dark:bg-gray-700 peer-checked:after:translate-x-full peer-checked:after:border-white after:content-[''] after:absolute after:top-[2px] after:left-[2px] after:bg-white after:border-gray-300 after:border after:rounded-full after:h-5 after:w-5 after:transition-all dark:border-gray-600 peer-checked:bg-blue-600" }, null, -1 /* HOISTED */);
const _hoisted_108 = /*#__PURE__*/createElementVNode("span", { class: "ml-3 text-sm font-medium text-gray-900 dark:text-gray-300" }, "Show latest trades", -1 /* HOISTED */);
const _hoisted_109 = { class: "mt-10 flex gap-1 justify-center" };
const _hoisted_110 = /*#__PURE__*/createStaticVNode("<div class=\"cb-style3\"><div data-modal-hide=\"staticModal\" type=\"button\" class=\"relative flex gap-2 items-center justify-center\"><span class=\"bg-[--color-primary-blue] rounded-full w-5 h-5 block border-1 border-[--color-primary-black]\"><svg class=\"scale-75 fill-[--color-primary-black]\" clip-rule=\"evenodd\" fill-rule=\"evenodd\" stroke-linejoin=\"round\" stroke-miterlimit=\"2\" viewBox=\"0 0 24 24\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"m9.831 16.198.002-.003-1.113-.996-.004.004-2.468-2.202c-.144-.128-.322-.191-.5-.191-.417 0-.749.337-.749.75 0 .206.084.412.249.56l2.478 2.21-.767.873-4.71-4.202c-.144-.128-.322-.191-.5-.191-.416 0-.749.337-.749.75 0 .206.084.412.25.56l5.268 4.7c.143.128.321.191.499.191.206 0 .41-.084.559-.25l1.264-1.437 1.677 1.496c.143.128.321.191.499.191.206 0 .409-.084.558-.25l11.234-12.499c.129-.143.192-.322.192-.501 0-.419-.338-.75-.748-.75-.206 0-.411.084-.559.249l-10.735 11.943zm-.451-1.75 1.114.996 8.316-9.182c.128-.143.191-.322.191-.501 0-.419-.337-.75-.748-.75-.206 0-.411.084-.559.249z\" fill-rule=\"nonzero\"></path></svg></span><span class=\"font-semibold\">Confirm</span></div></div>", 1);
const _hoisted_111 = /*#__PURE__*/createStaticVNode("<div data-modal-hide=\"staticModal\" type=\"button\" class=\"relative flex gap-2 items-center justify-center\"><span class=\"bg-[--color-primary-blue] rounded-full w-5 h-5 block border-1 border-[--color-primary-black] flex items-center justify-center\"><svg class=\"fill-[--color-primary-black]\" xmlns=\"http://www.w3.org/2000/svg\" width=\"11\" height=\"11\" viewBox=\"0 0 24 24\"><path d=\"M24 3.752l-4.423-3.752-7.771 9.039-7.647-9.008-4.159 4.278c2.285 2.885 5.284 5.903 8.362 8.708l-8.165 9.447 1.343 1.487c1.978-1.335 5.981-4.373 10.205-7.958 4.304 3.67 8.306 6.663 10.229 8.006l1.449-1.278-8.254-9.724c3.287-2.973 6.584-6.354 8.831-9.245z\"></path></svg></span><span class=\"font-semibold\">Cancel</span></div>", 1);
const _hoisted_112 = [
  _hoisted_111
];

function render(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createElementBlock("div", _hoisted_1, [
    createElementVNode("header", _hoisted_2, [
      createElementVNode("div", _hoisted_3, [
        _hoisted_4,
        createElementVNode("div", {
          class: normalizeClass([[$data.status === 0 ? 'red' : 'green'], "status mx-3"])
        }, null, 2 /* CLASS */),
        createElementVNode("div", _hoisted_5, toDisplayString($data.digitalClock), 1 /* TEXT */)
      ]),
      createVNode(Transition, null, {
        default: withCtx(() => [
          (!$data.tickers[$data.ticker])
            ? (openBlock(), createElementBlock("div", _hoisted_6, [
                createElementVNode("span", _hoisted_7, toDisplayString($options.statusMsg), 1 /* TEXT */)
              ]))
            : createCommentVNode("v-if", true)
        ]),
        _: 1 /* STABLE */
      }),
      createVNode(Transition, null, {
        default: withCtx(() => [
          ($data.tickers[$data.ticker])
            ? (openBlock(), createElementBlock("div", _hoisted_8, [
                createElementVNode("div", _hoisted_9, [
                  createElementVNode("div", _hoisted_10, [
                    createElementVNode("small", null, toDisplayString($data.tickers[$data.ticker]['pair']), 1 /* TEXT */),
                    createElementVNode("span", {
                      class: normalizeClass($data.tickers[$data.ticker]['style'])
                    }, [
                      createElementVNode("span", _hoisted_11, toDisplayString($data.tickers[$data.ticker]['arrow']), 1 /* TEXT */),
                      createElementVNode("span", null, toDisplayString($data.tickers[$data.ticker]['percent'].toFixed(2)) + "%", 1 /* TEXT */)
                    ], 2 /* CLASS */)
                  ]),
                  createElementVNode("div", null, [
                    createElementVNode("span", {
                      class: normalizeClass($data.tickers[$data.ticker]['style'])
                    }, toDisplayString($options.parseNumber($data.tickers[$data.ticker]['close'], $data.tickers[$data.ticker]['asset'])), 3 /* TEXT, CLASS */)
                  ])
                ]),
                createElementVNode("div", _hoisted_12, [
                  _hoisted_13,
                  createElementVNode("span", null, toDisplayString($options.parseNumber($data.tickers[$data.ticker]['high'], $data.tickers[$data.ticker]['asset'])), 1 /* TEXT */)
                ]),
                createElementVNode("div", _hoisted_14, [
                  _hoisted_15,
                  createElementVNode("span", null, toDisplayString($options.parseNumber($data.tickers[$data.ticker]['low'], $data.tickers[$data.ticker]['asset'])), 1 /* TEXT */)
                ]),
                createElementVNode("div", _hoisted_16, [
                  _hoisted_17,
                  createElementVNode("span", null, toDisplayString($options.parseNumber($data.tickers[$data.ticker]['tokenVolume'], $data.tickers[$data.ticker]['token'])) + " " + toDisplayString($data.tickers[$data.ticker]['token']), 1 /* TEXT */)
                ]),
                createElementVNode("div", _hoisted_18, [
                  _hoisted_19,
                  createElementVNode("span", null, toDisplayString($options.parseNumber($data.tickers[$data.ticker]['assetVolume'], $data.tickers[$data.ticker]['asset'])) + " " + toDisplayString($data.tickers[$data.ticker]['asset']), 1 /* TEXT */)
                ])
              ]))
            : createCommentVNode("v-if", true)
        ]),
        _: 1 /* STABLE */
      }),
      createElementVNode("div", {
        onClick: _cache[0] || (_cache[0] = (...args) => ($options.toggleSettings && $options.toggleSettings(...args))),
        class: "relative z-10 silver cursor-pointer"
      }, _hoisted_21)
    ]),
    _hoisted_22,
    createElementVNode("section", _hoisted_23, [
      createElementVNode("div", _hoisted_24, [
        createElementVNode("div", _hoisted_25, [
          createElementVNode("div", _hoisted_26, [
            _hoisted_27,
            _hoisted_28,
            createElementVNode("div", _hoisted_29, [
              _hoisted_30,
              withDirectives(createElementVNode("input", {
                "onUpdate:modelValue": _cache[1] || (_cache[1] = $event => (($data.inputSearch) = $event)),
                class: "w-full h-10 bg-transparent focus:outline-none",
                name: "query",
                placeholder: "Search...",
                type: "text"
              }, null, 512 /* NEED_PATCH */), [
                [vModelText, $data.inputSearch]
              ])
            ])
          ]),
          createElementVNode("div", _hoisted_31, [
            createElementVNode("ul", _hoisted_32, [
              createElementVNode("li", {
                onClick: _cache[2] || (_cache[2] = $event => ($options.filterAsset( 'USDT' ))),
                class: normalizeClass([[$data.asset === 'USDT' ? 'active' : ''], "cb2 flex flex-grow items-center justify-center cursor-pointer"])
              }, "USDT", 2 /* CLASS */),
              createElementVNode("li", {
                onClick: _cache[3] || (_cache[3] = $event => ($options.filterAsset( 'BTC' ))),
                class: normalizeClass([[$data.asset === 'BTC' ? 'active' : ''], "cb2 flex flex-grow items-center justify-center cursor-pointer"])
              }, "BTC", 2 /* CLASS */),
              createElementVNode("li", {
                onClick: _cache[4] || (_cache[4] = $event => ($options.filterAsset( 'FAV' ))),
                class: normalizeClass([[$data.asset === 'FAV' ? 'active' : ''], "cb2 flex flex-grow items-center justify-center cursor-pointer"])
              }, "FAV", 2 /* CLASS */)
            ])
          ]),
          createElementVNode("div", _hoisted_33, [
            createElementVNode("div", _hoisted_34, [
              createElementVNode("div", {
                onClick: _cache[5] || (_cache[5] = $event => ($options.sortBy( 'token', 'desc' ))),
                class: normalizeClass([[$data.sort === 'token' ? 'font-bold' : ''], "w-1/4"])
              }, "Pair", 2 /* CLASS */),
              createElementVNode("div", {
                onClick: _cache[6] || (_cache[6] = $event => ($options.sortBy( 'close', 'desc' ))),
                class: normalizeClass([[$data.sort === 'close' ? 'font-bold' : ''], "w-1/4 text-end"])
              }, "Price", 2 /* CLASS */),
              createElementVNode("div", {
                onClick: _cache[7] || (_cache[7] = $event => ($options.sortBy( 'percent', 'desc' ))),
                class: normalizeClass([[$data.sort === 'percent' ? 'font-bold' : ''], "w-1/4 text-end"])
              }, "Change", 2 /* CLASS */),
              createElementVNode("div", {
                onClick: _cache[8] || (_cache[8] = $event => ($options.sortBy( 'assetVolume', 'desc' ))),
                class: normalizeClass([[$data.sort === 'assetVolume' ? 'font-bold' : ''], "w-1/4 text-end pr-8"])
              }, "Volume", 2 /* CLASS */)
            ]),
            createElementVNode("div", _hoisted_35, [
              (Object.keys($data.tickers).length < 200)
                ? (openBlock(), createElementBlock("div", _hoisted_36, _hoisted_38))
                : (openBlock(), createElementBlock("div", _hoisted_39, [
                    (openBlock(true), createElementBlock(Fragment, null, renderList($options.filterTickers, (ticker) => {
                      return (openBlock(), createElementBlock("div", {
                        key: ticker.symbol,
                        class: "flex hover:bg-[#eab30840] cursor-pointer",
                        style: {"font-family":"'Roboto Mono', monospace"}
                      }, [
                        createElementVNode("div", {
                          onClick: $event => ($options.changeTicker(ticker.symbol)),
                          class: "w-1/4 dotdotdot silver"
                        }, [
                          createCommentVNode(" <img src=\"ticker.icon\" /> "),
                          createTextVNode(toDisplayString(ticker.pair), 1 /* TEXT */)
                        ], 8 /* PROPS */, _hoisted_40),
                        createElementVNode("div", {
                          onClick: $event => ($options.changeTicker(ticker.symbol)),
                          class: normalizeClass([ticker.style, "w-1/4 dotdotdot text-end"])
                        }, toDisplayString(ticker.close), 11 /* TEXT, CLASS, PROPS */, _hoisted_41),
                        createElementVNode("div", {
                          onClick: $event => ($options.changeTicker(ticker.symbol)),
                          class: normalizeClass([ticker.style, "w-1/4 dotdotdot text-end"])
                        }, toDisplayString(ticker.arrow) + " " + toDisplayString(ticker.percent.toFixed(2)), 11 /* TEXT, CLASS, PROPS */, _hoisted_42),
                        createElementVNode("div", _hoisted_43, [
                          createElementVNode("span", {
                            onClick: $event => ($options.changeTicker(ticker.symbol)),
                            class: "text-sm"
                          }, toDisplayString(ticker.assetVolume), 9 /* TEXT, PROPS */, _hoisted_44),
                          createElementVNode("span", {
                            onClick: $event => ($options.setFavorite(ticker.symbol))
                          }, [
                            (openBlock(), createElementBlock("svg", {
                              class: normalizeClass([$data.favorites.includes(ticker.symbol) ? 'fill-[--color-primary-yellow]' : 'fill-gray-400', "hover:fill-[--color-primary-yellow]"]),
                              xmlns: "http://www.w3.org/2000/svg",
                              width: "18",
                              height: "18",
                              viewBox: "0 0 24 24"
                            }, _hoisted_47, 2 /* CLASS */))
                          ], 8 /* PROPS */, _hoisted_45)
                        ])
                      ]))
                    }), 128 /* KEYED_FRAGMENT */))
                  ]))
            ])
          ])
        ]),
        createElementVNode("div", _hoisted_48, [
          createElementVNode("div", _hoisted_49, [
            _hoisted_50,
            createElementVNode("div", {
              onClick: _cache[9] || (_cache[9] = (...args) => ($options.toggleSettings && $options.toggleSettings(...args))),
              class: "relative z-10 silver cursor-pointer"
            }, _hoisted_52)
          ]),
          _hoisted_53,
          createElementVNode("div", _hoisted_54, [
            createElementVNode("div", { id: $data.container_id }, null, 8 /* PROPS */, _hoisted_55)
          ])
        ]),
        createElementVNode("div", _hoisted_56, [
          _hoisted_57,
          createElementVNode("div", null, [
            _hoisted_61,
            _hoisted_62,
            createElementVNode("div", _hoisted_63, [
              _hoisted_64,
              createElementVNode("div", _hoisted_65, [
                createElementVNode("div", _hoisted_66, [
                  createElementVNode("div", _hoisted_67, [
                    (openBlock(true), createElementBlock(Fragment, null, renderList($data.bids, (order) => {
                      return (openBlock(), createElementBlock("div", {
                        class: "flex gap-2",
                        style: normalizeStyle(`background: linear-gradient(to left, #00ff0030 0 ${(order[2] / $data.maxAsk) * 100}%, #ffffff00 ${(order[2] / $data.maxAsk) * 100}% 100%)`)
                      }, [
                        createElementVNode("div", _hoisted_68, toDisplayString($options.parseNumber((order[0] * order[1]), $data.asset)), 1 /* TEXT */),
                        createElementVNode("div", _hoisted_69, toDisplayString(parseFloat((order[1]))), 1 /* TEXT */),
                        createElementVNode("div", _hoisted_70, toDisplayString(parseFloat(order[0])), 1 /* TEXT */)
                      ], 4 /* STYLE */))
                    }), 256 /* UNKEYED_FRAGMENT */))
                  ]),
                  createElementVNode("div", _hoisted_71, [
                    (openBlock(true), createElementBlock(Fragment, null, renderList($data.asks, (order) => {
                      return (openBlock(), createElementBlock("div", {
                        class: "flex gap-2",
                        style: normalizeStyle(`background: linear-gradient(to right, #ff000030 0 ${(order[2] / $data.maxAsk) * 100}%, #ffffff00 ${(order[2] / $data.maxAsk) * 100}% 100%)`)
                      }, [
                        createElementVNode("div", _hoisted_72, toDisplayString(parseFloat(order[0])), 1 /* TEXT */),
                        createElementVNode("div", _hoisted_73, toDisplayString(parseFloat((order[1]))), 1 /* TEXT */),
                        createElementVNode("div", _hoisted_74, toDisplayString($options.parseNumber((order[0] * order[1]), $data.asset)), 1 /* TEXT */)
                      ], 4 /* STYLE */))
                    }), 256 /* UNKEYED_FRAGMENT */))
                  ])
                ])
              ])
            ])
          ])
        ])
      ])
    ]),
    createElementVNode("section", null, [
      createElementVNode("div", _hoisted_75, [
        _hoisted_76,
        createElementVNode("div", _hoisted_77, [
          createElementVNode("div", _hoisted_78, [
            createElementVNode("div", _hoisted_79, [
              _hoisted_80,
              createElementVNode("div", {
                onClick: _cache[10] || (_cache[10] = (...args) => ($options.toggleLatestTrades && $options.toggleLatestTrades(...args))),
                class: "relative z-10 silver cursor-pointer"
              }, [
                (openBlock(), createElementBlock("svg", {
                  class: normalizeClass([$data.showLatestTrades ? 'fill-[--color-primary-green] hover:fill-[--color-primary-red]' : 'fill-[--color-primary-red] hover:fill-[--color-primary-green]', "w-6"]),
                  "clip-rule": "evenodd",
                  "fill-rule": "evenodd",
                  "stroke-linejoin": "round",
                  "stroke-miterlimit": "2",
                  viewBox: "0 0 24 24",
                  xmlns: "http://www.w3.org/2000/svg"
                }, _hoisted_82, 2 /* CLASS */))
              ])
            ]),
            _hoisted_83,
            createElementVNode("div", _hoisted_84, [
              _hoisted_85,
              createElementVNode("div", _hoisted_86, [
                (openBlock(true), createElementBlock(Fragment, null, renderList($options.latestTrades, (trade, index) => {
                  return (openBlock(), createElementBlock("div", _hoisted_87, [
                    createElementVNode("div", _hoisted_88, toDisplayString($options.timestampToDate(trade[0])), 1 /* TEXT */),
                    createElementVNode("div", {
                      class: normalizeClass([[$data.trades[index+1] != undefined && $data.trades[index+1][1] > $data.trades[index][1] ? 'red' : 'green'], "w-1/3 text-end"])
                    }, toDisplayString(parseFloat(trade[1])), 3 /* TEXT, CLASS */),
                    createElementVNode("div", _hoisted_89, toDisplayString(parseFloat(trade[2])), 1 /* TEXT */)
                  ]))
                }), 256 /* UNKEYED_FRAGMENT */))
              ])
            ])
          ])
        ])
      ])
    ]),
    createCommentVNode(" Settings modal "),
    ($data.showSettings)
      ? (openBlock(), createElementBlock("div", _hoisted_90, [
          createElementVNode("div", _hoisted_91, [
            createCommentVNode(" Modal content "),
            createElementVNode("div", _hoisted_92, [
              createElementVNode("div", _hoisted_93, [
                createCommentVNode(" Modal header "),
                _hoisted_94,
                createCommentVNode(" Modal body "),
                createElementVNode("div", _hoisted_95, [
                  _hoisted_96,
                  createElementVNode("div", {
                    onClick: _cache[11] || (_cache[11] = (...args) => ($options.toggleLatestTrades && $options.toggleLatestTrades(...args))),
                    class: "relative inline-flex items-center cursor-pointer"
                  }, [
                    createElementVNode("input", {
                      type: "checkbox",
                      checked: $data.showLatestTrades ? true :false,
                      class: "sr-only peer"
                    }, null, 8 /* PROPS */, _hoisted_106),
                    _hoisted_107,
                    _hoisted_108
                  ])
                ])
              ]),
              createCommentVNode(" Modal footer "),
              createElementVNode("div", _hoisted_109, [
                _hoisted_110,
                createElementVNode("div", {
                  onClick: _cache[12] || (_cache[12] = (...args) => ($options.toggleSettings && $options.toggleSettings(...args))),
                  class: "cb-style3"
                }, _hoisted_112)
              ])
            ])
          ])
        ]))
      : createCommentVNode("v-if", true)
  ]))
}

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = "\n@import url('https://fonts.googleapis.com/css2?family=Rajdhani:wght@300;400;500;600;700&display=swap');\n@import url('https://fonts.googleapis.com/css2?family=Roboto+Mono:wght@100;200;300;400;700&display=swap');\nbody {\n    --color-bg--300: #1e181ef0;\n    --color-bg--500: #191a1e;\n    --color-primary--500: #e8615a;\n    --color-primary--600: #9c3230;\n    --color-primary-black: #0e0e18;\n    --color-primary-red: #710000;\n    --color-primary-yellow: #FDF500;\n    --color-primary-green: #1AC5B0;\n    --color-primary-blue: #37EBF3;\n    --color-primary-purple: #930DB;\n    --color-primary-pink1: #E455AE;\n    --color-primary-pink2: #CB1DCD;\n    --color-primary-silver: #D1C5C0;\n    --color-secondary-blue: #37EBF360;\n    --font-primary: \"Rajdhani\", sans-serif;\n    --font-secondary: \"VT323\", monospace;\n    --color-green: #1AC5B0;\n    --ui-glow: 0 0 5px var(--color-primary--500);\n    --ui-glow-borders--500: 0 0 3px var(--color-primary--500);\n    --ui-glow-color: currentcolor;\n    --ui-glow-text: -9px -6px 40px var(--ui-glow-color);\n    --ui-glow-text--dimmed: -9px -6px 40px var(--ui-glow-color);\n    --ui-elevation--1: 2px 2px 0 rgba(0, 0, 0, 0.8);\n    --ui-notch-amount: 1rem;\n    --ui-notch-hypotenuse: 22.627416px; /* hypothenuse of --ui-notch-amount */\n    --ui-notch-path: polygon(\n      0 0,\n      100% 0,\n      100% calc(100% - var(--ui-notch-amount) + 2px),\n      calc(100% - var(--ui-notch-amount) + 2px) 100%,\n      0 100%\n    );\n    --ui-notch-path-r: polygon(\n      100% 0,\n      100% 100%, \n      calc(var(--ui-notch-amount) - 2px) 100%, \n      0 calc(100% - var(--ui-notch-amount) + 2px), \n      0 0\n    );\n    font-family: var(--font-primary);\n    color: var(--color-primary--500);\n    background-color: var(--color-bg--500);\n    background-image: radial-gradient(\n      ellipse at 33% 10%,\n      #461616 0%,\n      transparent 75%\n    );\n    background-repeat: no-repeat;\n    margin: 0;\n}\nbody:before {\n  content: ' ';\n  display: block;\n  position: absolute;\n  left: 0;\n  top: 0;\n  width: 100%;\n  height: 100%;\n  opacity: 0.2;\n  background-image: url('https://images.unsplash.com/photo-1519608487953-e999c86e7455?ixlib=rb-4.0.3&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=1740&q=80');\n  background-repeat: no-repeat;\n  background-position: 50% 0;\n  background-size: cover;\n}\n#app {\n}\n.green {\n    color: var(--color-primary-green);\n}\n.red {\n    color: var(--color-primary--500);\n}\nsvg {\n    fill: currentcolor;\n}\n.text-glow {\n    font-family: var(--font-secondary);\n    color: var(--color-primary--500);\n    letter-spacing: 0.035rem;\n    text-shadow: var(--ui-glow-text);\n    text-transform: uppercase;\n}\nheader {\n    font-family: var(--font-secondary);\n    color: var(--color-primary-yellow);\n    letter-spacing: 0.035rem;\n    text-shadow: var(--ui-glow-text);\n    text-transform: uppercase;\n}\nh3 {\n}\nheader small {\n    color: var(--color-primary-silver);\n}\n.delimiter {\n    background-color: var(--color-primary--500);\n    box-shadow: var(--ui-glow);\n    bottom: 0;\n    content: \"\";\n    height: 2px;\n    left: 0;\n    width: 100%;\n}\n.delimiter2 {\n    background-color: var(--color-primary--500);\n    box-shadow: var(--ui-glow);\n    bottom: 0;\n    content: \"\";\n    height: 1px;\n    left: 0;\n    width: 100%;\n}\n.delimiter-blue {\n    background-color: var(--color-primary-blue);\n    box-shadow: var(--ui-glow);\n    bottom: 0;\n    content: \"\";\n    height: 1px;\n    left: 0;\n    width: 100%;\n}\n.status {\n    height: 8px;\n    width: 8px;\n    background-color: var(--color-primary-silver);\n    border-radius: 50%;\n    display: inline-block;\n}\n.status.green {\n    background-color: var(--color-primary-green);\n}\n.status.red {\n    background-color: var(--color-primary--500);\n}\n.silver {\n    color: var(--color-primary-silver);\n}\n.clock {\n    color: var(--color-primary-silver);\n}\n#vue-trading-view {\n    height: 600px;\n}\n.cb {\n    position: relative;\n    background-color: var(--color-bg--300);\n    border: 1px solid var(--color-primary--600);\n    -webkit-clip-path: var(--ui-notch-path);\n    clip-path: var(--ui-notch-path);\n}\n.cb::before {\n    background-color: var(--color-primary--600);\n    bottom: 5px;\n    content: \"\";\n    display: block;\n    height: 3px;\n    position: absolute;\n    right: -6px;\n    top: auto;\n    transform: rotate(-45deg);\n    width: var(--ui-notch-hypotenuse);\n    z-index: 100;\n}\n.cb-reverse {\n    clip-path: var(--ui-notch-path-r);\n}\n.cb-reverse::before {\n    transform: rotate(45deg);\n    left: -6px;\n}\n.cb2 {\n    position: relative;\n    background-color: var(--color-bg--300);\n    border: 1px solid var(--color-primary--600);\n    -webkit-clip-path: var(--ui-notch-path);\n    clip-path: var(--ui-notch-path);\n    padding-right: 0.5rem;\n}\n.cb2:hover, .cb2:hover::before, .cb2.active, .cb2.active::before {\n    border: 1px solid var(--color-primary-blue);\n    color: var(--color-primary-blue);\n    background-color: var(--color-secondary-blue);\n}\n.cb2::before {\n    background-color: var(--color-primary--600);\n    bottom: 5px;\n    content: \"\";\n    display: block;\n    height: 3px;\n    position: absolute;\n    right: -6px;\n    top: auto;\n    transform: rotate(-45deg);\n    width: var(--ui-notch-hypotenuse);\n    z-index: 100;\n}\n.cb_tab {\n  position: relative;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  font-size: 20px;\n  height: 50px; \n  min-width: 250px;\n  text-transform: uppercase;\n  letter-spacing: 0.035rem;\n  text-shadow: var(--ui-glow-text);\n  color: var(--color-primary--500);\n  background-color: var(--color-primary--600);\n  cursor: pointer;\n  border: 0;\n  outline: none;\n  clip-path: polygon(\n      4rem 0, \n      4.5rem 0.25rem, \n      100% 0.25rem, \n      100% calc(100% - var(--ui-notch-amount) + 2px),\n      calc(100% - var(--ui-notch-amount) + 2px) 100%, \n      0 100%, \n      0 0\n    );\n}\n.cb_tab:hover,\n  .cb_tab.active {\n  color: var(--color-primary-blue);\n}\n.cb_tab div {\n    position: absolute;\n    padding-top:5px;\n    top: 0.1rem;\n    left: 0.1rem;\n    right: 0.1rem;\n    bottom: 0.1rem;\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    background-color: var(--color-bg--300);\n    clip-path: polygon(\n        4rem 0, \n        4.5rem 0.25rem, \n        100% 0.25rem, \n        100% calc(100% - var(--ui-notch-amount) + 2px),\n        calc(100% - var(--ui-notch-amount) + 2px) 100%, \n        0 100%, \n        0 0\n    );\n}\n.cb-left {\n    position: relative;\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    font-size: 20px;\n    min-width: 35px;\n    text-transform: uppercase;\n    letter-spacing: 0.035rem;\n    background-color: #8921259c;\n    cursor: pointer;\n    border: 0;\n    outline: none;\n    clip-path: polygon(\n        20px 5px,\n        25px 0, \n        100% 0, \n        100% 50px,\n        calc(100% - 3px) 50px,\n        calc(100% - 3px) calc(100% - 50px),\n        100% calc(100% - 50px),\n        100% 100%,\n        1rem 100%, \n        0 calc(100% - var(--ui-notch-amount) + 2px), \n        0 5px\n      );\n}\n.cb-left div {\n    position: absolute;\n    padding-top:5px;\n    top: 0.1rem;\n    left: 0.1rem;\n    right: 0.1rem;\n    bottom: 0.1rem;\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    background-color: #441618;\n    clip-path: polygon(\n        20px 5px, \n        25px 0, \n        100% 0,\n        100% 50px,\n        calc(100% - 3px) 50px,\n        calc(100% - 3px) calc(100% - 50px),\n        100% calc(100% - 50px),\n        100% 100%,\n        1rem 100%, \n        0 calc(100% - var(--ui-notch-amount) + 2px), \n        0 5px\n    );\n}\n.cb-left div:after {\n    content: \"\";\n    display:block;\n    width: 20px;\n    height: 5px;\n    position: absolute;\n    z-index: 99;\n    left:0px;\n    background-color: transparent;\n    border: 1px solid #892125;\n}\n.cb-style3 {\n    position: relative;\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    font-size: 20px;\n    /*min-width: 250px;*/\n    height: 50px;\n    text-transform: uppercase;\n    letter-spacing: 0.035rem;\n    background-color: #892125;\n    cursor: pointer;\n    border: 0;\n    outline: none;\n    clip-path: var(--ui-notch-path);\n}\n.cb-style3::before {\n    content: \"\";\n    display:block;\n    position: absolute;\n    z-inde: -1;\n    top: 1px;\n    left: 1px;\n    right: 1px;\n    bottom: 1px;\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    background-color: #441618;\n    clip-path: var(--ui-notch-path);\n}\n.cb-style3::after {\n    content: \"\";\n    display:block;\n    width: 20px;\n    height: 5px;\n    position: absolute;\n    left:2px;\n    background-color: transparent;\n    border: 1px solid #892125;\n}\n.cb-style3:hover {\n    border: 1px solid var(--color-primary-blue);\n    color: var(--color-primary-blue);\n    background-color: var(--color-primary-blue);\n    z-index:10;\n}\n.cb-style3-left {\n    clip-path: var(--ui-notch-path-r);\n}\n.cb-style3-left::before {\n    clip-path: var(--ui-notch-path-r);\n}\n.cb-style3-left::after {\n    right:0;\n    transform: translateX(227px)\n}\n.cb-style3-left:hover::after {\n    border: 1px solid var(--color-primary-blue);\n}\n.tickers .header,\n  .trades .header,\n  .orders .header {\n    color:  var(--color-primary-blue);\n}\n.dotdotdot {\n    text-overflow: ellipsis;\n    white-space: nowrap;\n    overflow: hidden;\n}\n.orders .header > div,\n  .orders .body > div {\n     flex: 1;\n}\n.overflow-y-scroll::-webkit-scrollbar {\n  background: transparent;\n  width: 5px;\n}\n.overflow-y-scroll::-webkit-scrollbar-thumb {\n  background-color: var(--color-primary--500);\n}\n  \n  /* we will explain what these classes do next! */\n.v-enter-active,\n.v-leave-active {\n  opacity: 0;  \n  transition: opacity 0.5s ease;\n}\n.v-enter-from,\n.v-leave-to {\n  opacity: 0;\n  transition: opacity 0.5s ease;\n}\n\n";
styleInject(css_248z);

script.render = render;
script.__file = "tmp/codepen/vuejs/src/pen.vue";

export { script as default };